@@ -486,7 +486,10 @@ class PluginLoader:
                 continue
 
             if path not in self._module_cache:
-                module = self._load_module_source(name, path)
+                try:
+                    module = self._load_module_source(name, path)
+                except Exception as e:
+                    display.warning("Skipping plugin (%s) as it seems to be invalid: %s" % (path, to_text(e)))
                 self._module_cache[path] = module
                 found_in_cache = False
 
@@ -571,10 +574,9 @@ class Jinja2Loader(PluginLoader):
 
 def _load_plugin_filter():
     filters = defaultdict(frozenset)
-
+    user_set = False
     if C.PLUGIN_FILTERS_CFG is None:
-        filter_cfg = '/usr/local/etc/py27-ansible/plugin_filters.yml'
-        user_set = False
+        filter_cfg = '/usr/local/etc/ansible/plugin_filters.yml'
     else:
         filter_cfg = C.PLUGIN_FILTERS_CFG
         user_set = True
@@ -602,11 +604,17 @@ def _load_plugin_filter():
         if version == u'1.0':
             # Modules and action plugins share the same blacklist since the difference between the
             # two isn't visible to the users
-            filters['ansible.modules'] = frozenset(filter_data['module_blacklist'])
+            try:
+                filters['ansible.modules'] = frozenset(filter_data['module_blacklist'])
+            except TypeError:
+                display.warning(u'Unable to parse the plugin filter file {0} as'
+                                u' module_blacklist is not a list.'
+                                u' Skipping.'.format(filter_cfg))
+                return filters
             filters['ansible.plugins.action'] = filters['ansible.modules']
         else:
             display.warning(u'The plugin filter file, {0} was a version not recognized by this'
-                            u' version of Ansible. Skipping.')
+                            u' version of Ansible. Skipping.'.format(filter_cfg))
     else:
         if user_set:
             display.warning(u'The plugin filter file, {0} does not exist.'
